#! /usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = ["patrickzib"]

from distutils.core import setup

setup(name='scikit-series',
      version='0.0.1',
      description='Python Scikit-Time',
      author='patrickzib',
      author_email='patrick.schaefer@hu-berlin.de',
      url='https://github.com/patrickzib/dictionary',
     )